==> qore-0.8.12.2.tar.bz2: qore-0.8.12.2/docs/library/html/search/functions_74.js <==
var searchData=
[
  ['take',['take',['../class_qore_string.html#a229700be1f38e6b6572253d3202000ec',1,'QoreString::take(char *str)'],['../class_qore_string.html#aead54ebd0d023bb3e0f7b5408dcffd3d',1,'QoreString::take(char *str, const QoreEncoding *enc)'],['../class_qore_string.html#a8b16d3e9456767215ed202cb7a58f0c9',1,'QoreString::take(char *str, qore_size_t size)'],['../class_qore_string.html#a5fabd1c971b184ff7172b7ce53daf384',1,'QoreString::take(char *str, qore_size_t size, const QoreEncoding *enc)']]],
  ['take_5fhost',['take_host',['../class_qore_u_r_l.html#a8a91586f44fec17885b230fd0fca26d3',1,'QoreURL']]],
  ['take_5fpassword',['take_password',['../class_qore_u_r_l.html#a59f9dfdeb058db483b30cfae47008ae1',1,'QoreURL']]],
  ['take_5fpath',['take_path',['../class_qore_u_r_l.html#ae2cddbb14345d18099ac1f7490156720',1,'QoreURL']]],
  ['take_5fusername',['take_username',['../class_qore_u_r_l.html#aa655d40524987f03b3e60f686329d825',1,'QoreURL']]],
  ['takeaddress',['takeAddress',['../class_socket_source.html#afeb761e50534928de59ef8a5164924b5',1,'SocketSource']]],
  ['takeandterminate',['takeAndTerminate',['../class_qore_string.html#abb2d183e5d7922e01320e2f0dfd2a358',1,'QoreString::takeAndTerminate(char *str, qore_size_t size)'],['../class_qore_string.html#ab7ffa7a4a7552d79a14f559d3ed8625a',1,'QoreString::takeAndTerminate(char *str, qore_size_t size, const QoreEncoding *enc)']]],
  ['takeexists',['takeExists',['../class_qore_list_node.html#ab41f3537f295a5e24521777c14003e5f',1,'QoreListNode::takeExists()'],['../class_qore_value_list.html#ac0aebeef9bd0485ef939c99618734700',1,'QoreValueList::takeExists()']]],
  ['takehostname',['takeHostName',['../class_socket_source.html#a135049bc4ba6a6f237f65eb207f834eb',1,'SocketSource']]],
  ['takekeyvalue',['takeKeyValue',['../class_qore_hash_node.html#a9dc44385251490297d047711fd2b52d9',1,'QoreHashNode::takeKeyValue(const QoreString *key, ExceptionSink *xsink)'],['../class_qore_hash_node.html#a8588a55526fbc91ac9e1c4ed729aa879',1,'QoreHashNode::takeKeyValue(const char *key)']]],
  ['takemember',['takeMember',['../class_qore_object.html#a3b1560260c45a61ef2c9e2946c5077e6',1,'QoreObject::takeMember(const QoreString *key, ExceptionSink *xsink)'],['../class_qore_object.html#a5bfe7fcc05d40f4a1c9870d02173f927',1,'QoreObject::takeMember(const char *key, ExceptionSink *xsink)']]],
  ['takeprivatedata',['takePrivateData',['../class_s_q_l_statement.html#a81a9aa9142750015becf7842f8d2856e',1,'SQLStatement']]],
  ['takevalue',['takeValue',['../class_list_iterator.html#a371327a8312951f218ce0310280a2ddd',1,'ListIterator']]],
  ['takevalueanddelete',['takeValueAndDelete',['../class_hash_iterator.html#aef99a3e680fd313ded5f59686182955d',1,'HashIterator']]],
  ['tderef',['tDeref',['../class_qore_object.html#a53898d66c2c11d71667f3ad4c6f5baa3',1,'QoreObject']]],
  ['tempencodinghelper',['TempEncodingHelper',['../class_temp_encoding_helper.html#a9826d9519198b58f0d32b4cf761d1adf',1,'TempEncodingHelper::TempEncodingHelper(const QoreString &amp;s, const QoreEncoding *qe, ExceptionSink *xsink)'],['../class_temp_encoding_helper.html#a04677407f9b09ba256cfab96177a1f71',1,'TempEncodingHelper::TempEncodingHelper(const QoreString *s, const QoreEncoding *qe, ExceptionSink *xsink)'],['../class_temp_encoding_helper.html#a5d10492897dc2779672bc830ec2886d4',1,'TempEncodingHelper::TempEncodingHelper()']]],
  ['tempstring',['TempString',['../class_temp_string.html#a4ab1bfe679473a2abeec5472013596f6',1,'TempString::TempString()'],['../class_temp_string.html#aa3a8f9a2ae89915bcff183b27032cbc1',1,'TempString::TempString(const QoreEncoding *enc)'],['../class_temp_string.html#ac6e52e58589a5c8ebcf7683312cd2a8f',1,'TempString::TempString(QoreString *s)']]],
  ['terminate',['terminate',['../class_qore_string.html#a908834dd3a6f25855895bc77f668e5ba',1,'QoreString']]],
  ['test_5fbinary_5fparam',['test_binary_param',['../params_8h.html#ac9e70595153cf78104d4ba49f4325234',1,'params.h']]],
  ['test_5fcallref_5fparam',['test_callref_param',['../params_8h.html#af238b3a6723d1f23ed9cb1a2e12633ab',1,'params.h']]],
  ['test_5fdate_5fparam',['test_date_param',['../params_8h.html#af14bf3148e472ae0f40ef7163e60c2c2',1,'params.h']]],
  ['test_5ffuncref_5fparam',['test_funcref_param',['../params_8h.html#a42125ad28c900e10c13b360949cb6f3e',1,'params.h']]],
  ['test_5fhash_5fparam',['test_hash_param',['../params_8h.html#a68a28e59f8af9a959b7a4e355f3cfc0a',1,'params.h']]],
  ['test_5flist_5fparam',['test_list_param',['../params_8h.html#ab1650c62001799222df6d9fa5b2e197e',1,'params.h']]],
  ['test_5fnothing_5fparam',['test_nothing_param',['../params_8h.html#afe2edf110e562ff8946f484b93d5c35c',1,'params.h']]],
  ['test_5fobject_5fparam',['test_object_param',['../params_8h.html#a8f327c4fdfd43acdaf511850086fad66',1,'params.h']]],
  ['test_5freference_5fparam',['test_reference_param',['../params_8h.html#a581812bafd3008733f3a85145e06205e',1,'params.h']]],
  ['test_5fstring_5fparam',['test_string_param',['../params_8h.html#af9819236fe9544702f6281f63f90a95c',1,'params.h']]],
  ['tobigint',['toBigInt',['../class_qore_string.html#a23600f0d15794b530dc01f8966f9d912',1,'QoreString']]],
  ['tolwr',['tolwr',['../class_qore_string.html#af87e77070c828d6921d43ef02a1b8c9b',1,'QoreString']]],
  ['tonumber',['toNumber',['../class_qore_number_node.html#a3aeef3c1e7469f50debcd23fbba5fb82',1,'QoreNumberNode::toNumber(const AbstractQoreNode *v)'],['../class_qore_number_node.html#acd9af53a7fe301d7d29a371ab031a54d',1,'QoreNumberNode::toNumber(const QoreValue v)']]],
  ['tostring',['toString',['../class_qore_number_node.html#a88eba29e66f2d49c6fdc29b2d9906bc4',1,'QoreNumberNode']]],
  ['toupr',['toupr',['../class_qore_string.html#ab5a4ed54e09c248013075920e3fc16fd',1,'QoreString']]],
  ['tref',['tRef',['../class_qore_object.html#aa9ca336d993f52aec596553d444cbb94',1,'QoreObject']]],
  ['trim',['trim',['../class_qore_string.html#ab01190445a2f10d01b11f1f678a1fbd2',1,'QoreString::trim(const char *chars=0)'],['../class_qore_string.html#a91f9c29d355e5358d77a7ad1f35b2ed1',1,'QoreString::trim(char c)']]],
  ['trim_5fleading',['trim_leading',['../class_qore_string.html#a21cf9b80ab413d0d6038062e5aa5eaf3',1,'QoreString::trim_leading(const char *chars=0)'],['../class_qore_string.html#a9c17532a306567800e211a0500d10731',1,'QoreString::trim_leading(char c)']]],
  ['trim_5fsingle_5fleading',['trim_single_leading',['../class_qore_string.html#a1ac35de7fde8a05eb6047e6c3612ed5f',1,'QoreString']]],
  ['trim_5fsingle_5ftrailing',['trim_single_trailing',['../class_qore_string.html#a8b6e21435fb4ac870a20742412a79070',1,'QoreString']]],
  ['trim_5ftrailing',['trim_trailing',['../class_qore_string.html#a5f20a5629b714c3fd78029b6e8bc466e',1,'QoreString::trim_trailing(const char *chars=0)'],['../class_qore_string.html#a72740a303bf4d9fe8c917f3d66fdc744',1,'QoreString::trim_trailing(char c)']]],
  ['trylock',['trylock',['../class_qore_thread_lock.html#adda75d72ac351b96ce423830ce97cfe8',1,'QoreThreadLock']]],
  ['tryrdlock',['tryrdlock',['../class_qore_r_w_lock.html#afafd348fccf8d498a28ccf09ed5e0aa1',1,'QoreRWLock']]],
  ['trywrlock',['trywrlock',['../class_qore_r_w_lock.html#a97d41f7283e5686d52da3ac768a68c44',1,'QoreRWLock']]],
  ['tz_5fget_5fregion_5fname',['tz_get_region_name',['../_qore_lib_8h.html#acd716a7ff3752414b629563782ac74ee',1,'QoreLib.h']]],
  ['tz_5fget_5futc_5foffset',['tz_get_utc_offset',['../_qore_lib_8h.html#a3c77d47b856e27ac558da80df954f339',1,'QoreLib.h']]],
  ['tz_5fhas_5fdst',['tz_has_dst',['../_qore_lib_8h.html#af39cd296486a3aa681a8ef903c12d618',1,'QoreLib.h']]]
];

==> qore-0.8.13.5.tar.bz2: qore-0.8.13.5/docs/library/html/search/functions_74.js <==
var searchData=
[
  ['take',['take',['../class_qore_string.html#a229700be1f38e6b6572253d3202000ec',1,'QoreString::take(char *str)'],['../class_qore_string.html#aead54ebd0d023bb3e0f7b5408dcffd3d',1,'QoreString::take(char *str, const QoreEncoding *enc)'],['../class_qore_string.html#a8b16d3e9456767215ed202cb7a58f0c9',1,'QoreString::take(char *str, qore_size_t size)'],['../class_qore_string.html#a5fabd1c971b184ff7172b7ce53daf384',1,'QoreString::take(char *str, qore_size_t size, const QoreEncoding *enc)'],['../struct_qore_value.html#abb2900ab5a719f423bf1ae34fc41eea8',1,'QoreValue::take()']]],
  ['take_5fhost',['take_host',['../class_qore_u_r_l.html#a8a91586f44fec17885b230fd0fca26d3',1,'QoreURL']]],
  ['take_5fpassword',['take_password',['../class_qore_u_r_l.html#a59f9dfdeb058db483b30cfae47008ae1',1,'QoreURL']]],
  ['take_5fpath',['take_path',['../class_qore_u_r_l.html#ae2cddbb14345d18099ac1f7490156720',1,'QoreURL']]],
  ['take_5fusername',['take_username',['../class_qore_u_r_l.html#aa655d40524987f03b3e60f686329d825',1,'QoreURL']]],
  ['takeaddress',['takeAddress',['../class_socket_source.html#afeb761e50534928de59ef8a5164924b5',1,'SocketSource']]],
  ['takeandterminate',['takeAndTerminate',['../class_qore_string.html#abb2d183e5d7922e01320e2f0dfd2a358',1,'QoreString::takeAndTerminate(char *str, qore_size_t size)'],['../class_qore_string.html#ab7ffa7a4a7552d79a14f559d3ed8625a',1,'QoreString::takeAndTerminate(char *str, qore_size_t size, const QoreEncoding *enc)']]],
  ['takeexists',['takeExists',['../class_qore_value_list.html#ac0aebeef9bd0485ef939c99618734700',1,'QoreValueList']]],
  ['takehostname',['takeHostName',['../class_socket_source.html#a135049bc4ba6a6f237f65eb207f834eb',1,'SocketSource']]],
  ['takeifnode',['takeIfNode',['../struct_qore_value.html#a29a808a39ac08a2d0090709e84468a28',1,'QoreValue']]],
  ['takekeyvalue',['takeKeyValue',['../class_qore_hash_node.html#a9dc44385251490297d047711fd2b52d9',1,'QoreHashNode::takeKeyValue(const QoreString *key, ExceptionSink *xsink)'],['../class_qore_hash_node.html#a8588a55526fbc91ac9e1c4ed729aa879',1,'QoreHashNode::takeKeyValue(const char *key)']]],
  ['takemember',['takeMember',['../class_qore_object.html#a3b1560260c45a61ef2c9e2946c5077e6',1,'QoreObject::takeMember(const QoreString *key, ExceptionSink *xsink)'],['../class_qore_object.html#a5bfe7fcc05d40f4a1c9870d02173f927',1,'QoreObject::takeMember(const char *key, ExceptionSink *xsink)']]],
  ['takenode',['takeNode',['../struct_qore_value.html#a82a5cc470c39e02452d9c998436b83b3',1,'QoreValue::takeNode()'],['../class_value_optional_ref_holder.html#a2c039924774f5531ae333b0837c17f99',1,'ValueOptionalRefHolder::takeNode()']]],
  ['takenodeintern',['takeNodeIntern',['../struct_qore_value.html#ad40ebb7b142ce5bb02b6155fddceac1b',1,'QoreValue']]],
  ['takeprivatedata',['takePrivateData',['../class_s_q_l_statement.html#a81a9aa9142750015becf7842f8d2856e',1,'SQLStatement']]],
  ['takereferencednode',['takeReferencedNode',['../class_value_optional_ref_holder.html#af3adbb49502c05fb69120460a883c6d1',1,'ValueOptionalRefHolder']]],
  ['takereferencedvalue',['takeReferencedValue',['../class_value_optional_ref_holder.html#a8dfeab86150df96e8b4c8e005669bd8e',1,'ValueOptionalRefHolder']]],
  ['takevalue',['takeValue',['../class_list_iterator.html#a371327a8312951f218ce0310280a2ddd',1,'ListIterator::takeValue()'],['../class_value_optional_ref_holder.html#a59b9c2a7c32416c988270ccdbca3e87a',1,'ValueOptionalRefHolder::takeValue()']]],
  ['takevalueanddelete',['takeValueAndDelete',['../class_hash_iterator.html#aef99a3e680fd313ded5f59686182955d',1,'HashIterator']]],
  ['takevaluefrom',['takeValueFrom',['../class_value_optional_ref_holder.html#af6e3fdde352befe43f0c7ccb20913ad5',1,'ValueOptionalRefHolder']]],
  ['tderef',['tDeref',['../class_qore_object.html#a53898d66c2c11d71667f3ad4c6f5baa3',1,'QoreObject']]],
  ['tempencodinghelper',['TempEncodingHelper',['../class_temp_encoding_helper.html#a9826d9519198b58f0d32b4cf761d1adf',1,'TempEncodingHelper::TempEncodingHelper(const QoreString &amp;s, const QoreEncoding *qe, ExceptionSink *xsink)'],['../class_temp_encoding_helper.html#a04677407f9b09ba256cfab96177a1f71',1,'TempEncodingHelper::TempEncodingHelper(const QoreString *s, const QoreEncoding *qe, ExceptionSink *xsink)'],['../class_temp_encoding_helper.html#a5d10492897dc2779672bc830ec2886d4',1,'TempEncodingHelper::TempEncodingHelper()']]],
  ['tempstring',['TempString',['../class_temp_string.html#a4ab1bfe679473a2abeec5472013596f6',1,'TempString::TempString()'],['../class_temp_string.html#aa3a8f9a2ae89915bcff183b27032cbc1',1,'TempString::TempString(const QoreEncoding *enc)'],['../class_temp_string.html#ac6e52e58589a5c8ebcf7683312cd2a8f',1,'TempString::TempString(QoreString *s)']]],
  ['terminate',['terminate',['../class_qore_string.html#a908834dd3a6f25855895bc77f668e5ba',1,'QoreString']]],
  ['test_5fbinary_5fparam',['test_binary_param',['../params_8h.html#ac9e70595153cf78104d4ba49f4325234',1,'params.h']]],
  ['test_5fcallref_5fparam',['test_callref_param',['../params_8h.html#af238b3a6723d1f23ed9cb1a2e12633ab',1,'params.h']]],
  ['test_5fdate_5fparam',['test_date_param',['../params_8h.html#af14bf3148e472ae0f40ef7163e60c2c2',1,'params.h']]],
  ['test_5ffuncref_5fparam',['test_funcref_param',['../params_8h.html#a42125ad28c900e10c13b360949cb6f3e',1,'params.h']]],
  ['test_5fhash_5fparam',['test_hash_param',['../params_8h.html#a68a28e59f8af9a959b7a4e355f3cfc0a',1,'params.h']]],
  ['test_5flist_5fparam',['test_list_param',['../params_8h.html#ab1650c62001799222df6d9fa5b2e197e',1,'params.h']]],
  ['test_5fnothing_5fparam',['test_nothing_param',['../params_8h.html#afe2edf110e562ff8946f484b93d5c35c',1,'params.h']]],
  ['test_5fobject_5fparam',['test_object_param',['../params_8h.html#a8f327c4fdfd43acdaf511850086fad66',1,'params.h']]],
  ['test_5freference_5fparam',['test_reference_param',['../params_8h.html#a581812bafd3008733f3a85145e06205e',1,'params.h']]],
  ['test_5fstring_5fparam',['test_string_param',['../params_8h.html#af9819236fe9544702f6281f63f90a95c',1,'params.h']]],
  ['tobigint',['toBigInt',['../class_qore_string.html#a23600f0d15794b530dc01f8966f9d912',1,'QoreString']]],
  ['tolwr',['tolwr',['../class_qore_string.html#af87e77070c828d6921d43ef02a1b8c9b',1,'QoreString']]],
  ['tonumber',['toNumber',['../class_qore_number_node.html#a3aeef3c1e7469f50debcd23fbba5fb82',1,'QoreNumberNode::toNumber(const AbstractQoreNode *v)'],['../class_qore_number_node.html#acd9af53a7fe301d7d29a371ab031a54d',1,'QoreNumberNode::toNumber(const QoreValue v)']]],
  ['tostring',['toString',['../class_qore_number_node.html#a88eba29e66f2d49c6fdc29b2d9906bc4',1,'QoreNumberNode']]],
  ['toupr',['toupr',['../class_qore_string.html#ab5a4ed54e09c248013075920e3fc16fd',1,'QoreString']]],
  ['transform',['Transform',['../class_transform.html#a144ce8dcafd13ca66acb5a1636cfc297',1,'Transform']]],
  ['tref',['tRef',['../class_qore_object.html#aa9ca336d993f52aec596553d444cbb94',1,'QoreObject']]],
  ['trim',['trim',['../class_qore_string.html#ab01190445a2f10d01b11f1f678a1fbd2',1,'QoreString::trim(const char *chars=0)'],['../class_qore_string.html#a91f9c29d355e5358d77a7ad1f35b2ed1',1,'QoreString::trim(char c)'],['../class_qore_string.html#a0c38e16553406179c5a1e364815f5e01',1,'QoreString::trim(ExceptionSink *xsink, const QoreString *chars=nullptr)']]],
  ['trim_5fleading',['trim_leading',['../class_qore_string.html#a21cf9b80ab413d0d6038062e5aa5eaf3',1,'QoreString::trim_leading(const char *chars=0)'],['../class_qore_string.html#a9c17532a306567800e211a0500d10731',1,'QoreString::trim_leading(char c)']]],
  ['trim_5fsingle_5fleading',['trim_single_leading',['../class_qore_string.html#a1ac35de7fde8a05eb6047e6c3612ed5f',1,'QoreString']]],
  ['trim_5fsingle_5ftrailing',['trim_single_trailing',['../class_qore_string.html#a8b6e21435fb4ac870a20742412a79070',1,'QoreString']]],
  ['trim_5ftrailing',['trim_trailing',['../class_qore_string.html#a5f20a5629b714c3fd78029b6e8bc466e',1,'QoreString::trim_trailing(const char *chars=0)'],['../class_qore_string.html#a72740a303bf4d9fe8c917f3d66fdc744',1,'QoreString::trim_trailing(char c)']]],
  ['trimleading',['trimLeading',['../class_qore_string.html#ad6056142ed30ad79f57c29c19206ac91',1,'QoreString']]],
  ['trimtrailing',['trimTrailing',['../class_qore_string.html#a3ca58f75a2f956c5049f35fbe560bfc4',1,'QoreString']]],
  ['trygetreferencedprivatedata',['tryGetReferencedPrivateData',['../class_qore_object.html#a65a7ac25045e07ad9399b78f13f12576',1,'QoreObject']]],
  ['trylock',['trylock',['../class_qore_thread_lock.html#adda75d72ac351b96ce423830ce97cfe8',1,'QoreThreadLock']]],
  ['tryrdlock',['tryrdlock',['../class_qore_r_w_lock.html#afafd348fccf8d498a28ccf09ed5e0aa1',1,'QoreRWLock']]],
  ['trywrlock',['trywrlock',['../class_qore_r_w_lock.html#a97d41f7283e5686d52da3ac768a68c44',1,'QoreRWLock']]],
  ['typedhashdeclholder',['TypedHashDeclHolder',['../class_typed_hash_decl_holder.html#ac64fbf6f7bcdcf55c52debbeaac85bb8',1,'TypedHashDeclHolder']]],
  ['tz_5fget_5fregion_5fname',['tz_get_region_name',['../_qore_lib_8h.html#acd716a7ff3752414b629563782ac74ee',1,'QoreLib.h']]],
  ['tz_5fget_5futc_5foffset',['tz_get_utc_offset',['../_qore_lib_8h.html#a3c77d47b856e27ac558da80df954f339',1,'QoreLib.h']]],
  ['tz_5fhas_5fdst',['tz_has_dst',['../_qore_lib_8h.html#af39cd296486a3aa681a8ef903c12d618',1,'QoreLib.h']]]
];
